TLS Canary
==========

`TLS Canary <https://github.com/mozilla/tls-canary>`_ is a
`TLS/SSL <https://en.wikipedia.org/wiki/Transport_Layer_Security>`_ testing framework for the
`Mozilla Firefox <https://www.mozilla.org/firefox>`_ web browser. It is used by developers to run
regression and performance tests against a large number of HTTPS-enabled hosts on the Internet.

--------

The TLS Canary Python package has several non-Python dependencies that need to be satisfied for the script to run.
For installation instructions, usage information, and issue tracking, please visit the `Project Page
<https://github.com/mozilla/tls-canary>`_ on GitHub.
